﻿/*
  KeeUIExt Plugin
  Copyright (C) 2014 Dominik Reichl <dominik.reichl@t-online.de>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;

using KeePass.Forms;
using KeePass.Plugins;
using KeePass.Resources;
using KeePass.UI;

using KeePassLib.Utility;

namespace KeeUIExt
{
	public sealed class KeeUIExtExt : Plugin
	{
		private IPluginHost m_host = null;

		private const string ProductName = "KeeUIExt";

		private const string CkPrefix = ProductName + "_";
		private const string CkConfirmDbClosing = CkPrefix + "ConfirmDbClosing";

		public override bool Initialize(IPluginHost host)
		{
			Terminate();

			if(host == null) return false;
			m_host = host;

			m_host.MainWindow.FileClosingPre += this.OnFileClosingPre;

			return true;
		}

		public override void Terminate()
		{
			if(m_host == null) return;

			m_host.MainWindow.FileClosingPre -= this.OnFileClosingPre;

			m_host = null;
		}

		private void OnFileClosingPre(object sender, FileClosingEventArgs e)
		{
			bool bConfirm = m_host.CustomConfig.GetBool(CkConfirmDbClosing, true);
			if(!bConfirm) return;

			string strQ = "Are you sure you want to close the database?";
			string strDatabase = e.Database.IOConnectionInfo.GetDisplayName();

			VistaTaskDialog vtd = new VistaTaskDialog();
			vtd.CommandLinks = false;
			vtd.Content = strDatabase;
			vtd.MainInstruction = strQ;
			vtd.SetIcon(VtdCustomIcon.Question);
			vtd.VerificationText = KPRes.DialogNoShowAgain;
			vtd.WindowTitle = KeeUIExtExt.ProductName;

			vtd.AddButton((int)DialogResult.OK, KPRes.YesCmd, null);
			vtd.AddButton((int)DialogResult.Cancel, KPRes.NoCmd, null);

			if(vtd.ShowDialog())
			{
				if((vtd.Result == (int)DialogResult.OK) || (vtd.Result ==
					(int)DialogResult.Yes))
				{
					if(vtd.ResultVerificationChecked)
						m_host.CustomConfig.SetBool(CkConfirmDbClosing, false);
				}
				else e.Cancel = true;
			}
			else
			{
				if(!MessageService.AskYesNo(strDatabase + MessageService.NewParagraph +
					strQ, KeeUIExtExt.ProductName))
					e.Cancel = true;
			}
		}
	}
}
